## Changelog
This document specifies changes to the library, each version released will contain patch notes detailing the purpose
of the update.

#### Subsections
- `Added`: New features that have been released
- `Changes`: Updates to existing functionality
- `Deprecated`: Once stable features that are scheduled for removal in the future
- `Removed`: Features that have been officially removed from the release
- `Fixed`: Patches that resolve known issues in the API
-
### 2019-03-28
--------------
Version: 0.1.0
- `Added` Initial pre-production release of the library
